'/****************************************************************************
' BASS_FX 2.4 - Copyright (c) 2002-2008 (: JOBnik! :) [Arthur Aminov, ISRAEL]
'                                                     [http://www.jobnik.org]

'     bugs/suggestions/questions:
'       forum  : http://www.un4seen.com/forum/?board=1
'               http://www.jobnik.org/smforum
'       e-mail : bass_fx@jobnik.org
'     --------------------------------------------------

' NOTE: This header will work only with BASS_FX version 2.4
'       Check www.un4seen.com or www.jobnik.org for any later versions.

' * Requires BASS 2.4 (available @ www.un4seen.com)
'****************************************************************************/

#IF NOT %DEF(%BASS_FX_INC)
    %BASS_FX_INC = 1

'// Error codes returned by BASS_ErrorGetCode()
%BASS_ERROR_FX_NODECODE     = 4000  ' // Not a decoding channel
%BASS_ERROR_FX_BPMINUSE     = 4001  ' // BPM/Beat detection is in use

'// Tempo / Reverse / BPM / Beat flag
%BASS_FX_FREESOURCE         = &H10000???  ' // Free the source handle as well?

'// BASS_FX Version
' ========================================================================================
' DWORD BASS_FXDEF(BASS_FX_GetVersion)();
' ========================================================================================
DECLARE FUNCTION BASS_FX_GetVersion LIB "bass_fx.dll" ALIAS "BASS_FX_GetVersion" ( _
 ) AS DWORD                                   ' DWORD


'/*=============================================================================================
'   D S P (Digital Signal Processing)
'==============================================================================================*/

'/*
'   Multi-channel order of each channel is as follows:
'    3 channels       left-front, right-front, center.
'    4 channels       left-front, right-front, left-rear/side, right-rear/side.
'    6 channels (5.1) left-front, right-front, center, LFE, left-rear/side, right-rear/side.
'    8 channels (7.1) left-front, right-front, center, LFE, left-rear/side, right-rear/side, left-rear center, right-rear center.
'*/

'// DSP channels flags
%BASS_BFX_CHANALL  = -1    ' // all channels at once (as by default)
%BASS_BFX_CHANNONE = 0     ' // disable an effect for all channels
%BASS_BFX_CHAN1    = 1     ' // left-front channel
%BASS_BFX_CHAN2    = 2     ' // right-front channel
%BASS_BFX_CHAN3    = 4     ' // see above info
%BASS_BFX_CHAN4    = 8     ' // see above info
%BASS_BFX_CHAN5    = 16    ' // see above info
%BASS_BFX_CHAN6    = 32    ' // see above info
%BASS_BFX_CHAN7    = 64    ' // see above info
%BASS_BFX_CHAN8    = 128   ' // see above info

'// if you have more than 8 channels, use this macro
'#define BASS_BFX_CHANNEL_N(n) (1<<((n)-1))
MACRO BASS_BFX_CHANNEL_N(n) = 2 ^ (n - 1)

'// DSP effects
%BASS_FX_BFX_ROTATE     = &H10000???                    ' ' // A channels volume ping-pong   / stereo
%BASS_FX_BFX_ECHO       = %BASS_FX_BFX_ROTATE     + 1   ' // Echo                     / 2 channels max
%BASS_FX_BFX_FLANGER    = %BASS_FX_BFX_ECHO       + 1   ' // Flanger                  / multi channel
%BASS_FX_BFX_VOLUME     = %BASS_FX_BFX_FLANGER    + 1   ' // Volume                  / multi channel
%BASS_FX_BFX_PEAKEQ     = %BASS_FX_BFX_VOLUME     + 1   ' // Peaking Equalizer         / multi channel
%BASS_FX_BFX_REVERB     = %BASS_FX_BFX_PEAKEQ     + 1   ' // Reverb                  / 2 channels max
%BASS_FX_BFX_LPF        = %BASS_FX_BFX_REVERB     + 1   ' // Low Pass Filter            / multi channel
%BASS_FX_BFX_MIX        = %BASS_FX_BFX_LPF        + 1   ' // Swap, remap and mix channels   / multi channel
%BASS_FX_BFX_DAMP       = %BASS_FX_BFX_MIX        + 1   ' // Dynamic Amplification      / multi channel
%BASS_FX_BFX_AUTOWAH    = %BASS_FX_BFX_DAMP       + 1   ' // Auto WAH                  / multi channel
%BASS_FX_BFX_ECHO2      = %BASS_FX_BFX_AUTOWAH    + 1   ' // Echo 2                  / multi channel
%BASS_FX_BFX_PHASER     = %BASS_FX_BFX_ECHO2      + 1   ' // Phaser                  / multi channel
%BASS_FX_BFX_ECHO3      = %BASS_FX_BFX_PHASER     + 1   ' // Echo 3                  / multi channel
%BASS_FX_BFX_CHORUS     = %BASS_FX_BFX_ECHO3      + 1   ' // Chorus                  / multi channel
%BASS_FX_BFX_APF        = %BASS_FX_BFX_CHORUS     + 1   ' // All Pass Filter            / multi channel
%BASS_FX_BFX_COMPRESSOR = %BASS_FX_BFX_APF        + 1   ' // Compressor               / multi channel
%BASS_FX_BFX_DISTORTION = %BASS_FX_BFX_COMPRESSOR + 1   ' // Distortion               / multi channel

'// Echo
TYPE BASS_BFX_ECHO
   fLevel AS SINGLE   ' float // [0....1....n] linear
   lDelay AS LONG     ' int   // [1200..30000]
END TYPE

'// Flanger
TYPE BASS_BFX_FLANGER
   fWetDry  AS SINGLE   ' float // [0....1....n] linear
   fSpeed   AS SINGLE   ' float // [0......0.09]
   lChannel AS LONG     ' int   // BASS_BFX_CHANxxx flag/s
END TYPE

'// Volume
TYPE BASS_BFX_VOLUME
   lChannel AS LONG     ' int // BASS_BFX_CHANxxx flag/s or 0 for global volume control
   fVolume  AS SINGLE   ' float // [0....1....n] linear
END TYPE

'// Peaking Equalizer
TYPE BASS_BFX_PEAKEQ
   lBand      AS LONG     ' int   // [0...............n] more bands means more memory & cpu usage
   fBandwidth AS SINGLE   ' float // [0.1.....4.......n] in octaves - Q is not in use (BW has a priority over Q)
   fQ         AS SINGLE   ' float // [0.......1.......n] the EE kinda definition (linear) (if Bandwidth is not in use)
   fCenter    AS SINGLE   ' float // [1Hz..<info.freq/2] in Hz
   fGain      AS SINGLE   ' float // [-15dB...0...+15dB] in dB
   lChannel   AS LONG     ' int   // BASS_BFX_CHANxxx flag/s
END TYPE

'// Reverb
TYPE BASS_BFX_REVERB
   fLevel AS SINGLE   ' float // [0....1....n] linear
   lDelay AS LONG     ' int   // [1200..10000]
END TYPE

'// Low Pass Filter
TYPE BASS_BFX_LPF
   fResonance  AS SINGLE   ' float // [0.01...........10]
   fCutOffFreq AS SINGLE   ' float // [1Hz...info.freq/2] cutoff frequency
   lChannel    AS LONG     ' int   // BASS_BFX_CHANxxx flag/s
END TYPE

'// Swap, remap and mix
TYPE BASS_BFX_MIX
   lChannel AS LONG PTR   ' int * // an array of channels to mix using BASS_BFX_CHANxxx flag/s (lChannel[0] is left channel...)
END TYPE

'// Dynamic Amplification
TYPE BASS_BFX_DAMP
   fTarget  AS SINGLE   ' float // target volume level                  [0<......1] linear
   fQuiet   AS SINGLE   ' float // quiet  volume level                  [0.......1] linear
   fRate    AS SINGLE   ' float // amp adjustment rate                  [0.......1] linear
   fGain    AS SINGLE   ' float // amplification level                  [0...1...n] linear
   fDelay   AS SINGLE   ' float // delay in seconds before increasing level   [0.......n] linear
   lChannel AS LONG     ' int   // BASS_BFX_CHANxxx flag/s
END TYPE

'// Auto WAH
TYPE BASS_BFX_AUTOWAH
   fDryMix   AS SINGLE   ' float // dry (unaffected) signal mix          [-2......2]
   fWetMix   AS SINGLE   ' float // wet (affected) signal mix            [-2......2]
   fFeedback AS SINGLE   ' float // feedback                             [-1......1]
   fRate     AS SINGLE   ' float // rate of sweep in cycles per second   [0<....<10]
   fRange    AS SINGLE   ' float // sweep range in octaves               [0<....<10]
   fFreq     AS SINGLE   ' float // base frequency of sweep Hz           [0<...1000]
   lChannel  AS LONG     ' int   // BASS_BFX_CHANxxx flag/s
END TYPE

'// Echo 2
TYPE BASS_BFX_ECHO2
   fDryMix   AS SINGLE   ' float // dry (unaffected) signal mix          [-2......2]
   fWetMix   AS SINGLE   ' float // wet (affected) signal mix            [-2......2]
   fFeedback AS SINGLE   ' float // feedback                             [-1......1]
   fDelay    AS SINGLE   ' float // delay sec                            [0<......6]
   lChannel  AS LONG     ' int   // BASS_BFX_CHANxxx flag/s
END TYPE

'// Phaser
TYPE BASS_BFX_PHASER
   fDryMix   AS SINGLE   ' float // dry (unaffected) signal mix          [-2......2]
   fWetMix   AS SINGLE   ' float // wet (affected) signal mix            [-2......2]
   fFeedback AS SINGLE   ' float // feedback                             [-1......1]
   fRate     AS SINGLE   ' float // rate of sweep in cycles per second   [0<....<10]
   fRange    AS SINGLE   ' float // sweep range in octaves               [0<....<10]
   fFreq     AS SINGLE   ' float // base frequency of sweep              [0<...1000]
   lChannel  AS LONG     ' int   // BASS_BFX_CHANxxx flag/s
END TYPE

'// Echo 3
TYPE BASS_BFX_ECHO3
   fDryMix AS SINGLE   ' float // dry (unaffected) signal mix          [-2......2]
   fWetMix AS SINGLE   ' float // wet (affected) signal mix            [-2......2]
   fDelay AS SINGLE    ' float // delay sec                            [0<......6]
   lChannel AS LONG    ' int   // BASS_BFX_CHANxxx flag/s
END TYPE

'// Chorus
TYPE BASS_BFX_CHORUS
   fDryMix   AS SINGLE   ' float // dry (unaffected) signal mix        [-2......2]
   fWetMix   AS SINGLE   ' float // wet (affected) signal mix          [-2......2]
   fFeedback AS SINGLE   ' float // feedback                           [-1......1]
   fMinSweep AS SINGLE   ' float // minimal delay ms                   [0<...6000]
   fMaxSweep AS SINGLE   ' float // maximum delay ms                   [0<...6000]
   fRate     AS SINGLE   ' float // rate ms/s                          [0<...1000]
   lChannel  AS LONG     ' int   // BASS_BFX_CHANxxx flag/s
END TYPE

'// All Pass Filter
TYPE BASS_BFX_APF
   fGain AS SINGLE    ' float // reverberation time               [-1=<..<=1]
   fDelay AS SINGLE   ' float // delay sec                        [0<....<=6]
   lChannel AS LONG   ' int   // BASS_BFX_CHANxxx flag/s
END TYPE

'// Compressor
TYPE BASS_BFX_COMPRESSOR
   fThreshold   AS SINGLE   ' float // compressor threshold       [0<=...<=1]
   fAttacktime  AS SINGLE   ' float // attack time ms             [0<.<=1000]
   fReleasetime AS SINGLE   ' float // release time ms            [0<.<=5000]
   lChannel     AS LONG     ' int  // BASS_BFX_CHANxxx flag/s
END TYPE

'// Distortion
TYPE BASS_BFX_DISTORTION
   fDrive    AS SINGLE   ' float // distortion drive                   [0<=...<=5]
   fDryMix   AS SINGLE   ' float // dry (unaffected) signal mix        [-5<=..<=5]
   fWetMix   AS SINGLE   ' float // wet (affected) signal mix          [-5<=..<=5]
   fFeedback AS SINGLE   ' float // feedback                           [-1<=..<=1]
   fVolume   AS SINGLE   ' float // distortion volume                  [0=<...<=2]
   lChannel  AS LONG     ' int   // BASS_BFX_CHANxxx flag/s
END TYPE

'/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
'   set dsp fx - BASS_ChannelSetFX
' =============================================================================================
'   remove dsp fx - BASS_ChannelRemoveFX
' =============================================================================================
'   set parameters - BASS_FXSetParameters
' =============================================================================================
'   retrieve parameters - BASS_FXGetParameters
' =============================================================================================
'   reset the state - BASS_FXReset
'=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=*/

'/*=============================================================================================
'   TEMPO / PITCH SCALING / SAMPLERATE
'==============================================================================================*/

'// NOTES: 1. Supported ONLY - mono / stereo - channels
'//        2. Enable Tempo supported flags in BASS_FX_TempoCreate and the others to source handle.

'// tempo attributes (BASS_ChannelSet/GetAttribute)
%BASS_ATTRIB_TEMPO       = &H10000???
%BASS_ATTRIB_TEMPO_PITCH = %BASS_ATTRIB_TEMPO       + 1
%BASS_ATTRIB_TEMPO_FREQ  = %BASS_ATTRIB_TEMPO_PITCH + 1

'// tempo attributes options
'// [option]                                 [value]
%BASS_ATTRIB_TEMPO_OPTION_USE_AA_FILTER    = &H10010???                                       ' // TRUE / FALSE
%BASS_ATTRIB_TEMPO_OPTION_AA_FILTER_LENGTH = %BASS_ATTRIB_TEMPO_OPTION_USE_AA_FILTER    + 1   ' // 32 default (8 .. 128 taps)
%BASS_ATTRIB_TEMPO_OPTION_USE_QUICKALGO    = %BASS_ATTRIB_TEMPO_OPTION_AA_FILTER_LENGTH + 1   ' // TRUE / FALSE
%BASS_ATTRIB_TEMPO_OPTION_SEQUENCE_MS      = %BASS_ATTRIB_TEMPO_OPTION_USE_QUICKALGO    + 1   ' // 82 default
%BASS_ATTRIB_TEMPO_OPTION_SEEKWINDOW_MS    = %BASS_ATTRIB_TEMPO_OPTION_SEQUENCE_MS      + 1   ' // 14 default
%BASS_ATTRIB_TEMPO_OPTION_OVERLAP_MS       = %BASS_ATTRIB_TEMPO_OPTION_SEEKWINDOW_MS    + 1   ' // 12 default

' ========================================================================================
' Creates a resampling stream from a decoding channel.
' HSTREAM BASS_FXDEF(BASS_FX_TempoCreate)(DWORD chan, DWORD flags);
' ========================================================================================
DECLARE FUNCTION BASS_FX_TempoCreate LIB "bass_fx.dll" ALIAS "BASS_FX_TempoCreate" ( _
   BYVAL DWORD _                              ' __in DWORD chan
 , BYVAL DWORD _                              ' __in DWORD flags
 ) AS DWORD                                   ' HSTREAM

' ========================================================================================
' Get the source channel handle.
' DWORD BASS_FXDEF(BASS_FX_TempoGetSource)(HSTREAM chan);
' ========================================================================================
DECLARE FUNCTION BASS_FX_TempoGetSource LIB "bass_fx.dll" ALIAS "BASS_FX_TempoGetSource" ( _
   BYVAL DWORD _                              ' __in HSTREAM chan
 ) AS DWORD                                   ' DWORD

' ========================================================================================
' Get the ratio of the resulting rate and source rate (the resampling ratio).
' float BASS_FXDEF(BASS_FX_TempoGetRateRatio)(HSTREAM chan);
' ========================================================================================
DECLARE FUNCTION BASS_FX_TempoGetRateRatio LIB "bass_fx.dll" ALIAS "BASS_FX_TempoGetRateRatio" ( _
   BYVAL DWORD _                              ' __in HSTREAM chan
 ) AS SINGLE                                  ' float

'/*=============================================================================================
'   R E V E R S E
'==============================================================================================*/

'// NOTES: 1. MODs won't load without BASS_MUSIC_PRESCAN flag.
'//        2. Enable Reverse supported flags in BASS_FX_ReverseCreate and the others to source handle.

'// reverse attribute (BASS_ChannelSet/GetAttribute)
%BASS_ATTRIB_REVERSE_DIR = &H11000???

'// playback directions
%BASS_FX_RVS_REVERSE = -1
%BASS_FX_RVS_FORWARD = 1

' ========================================================================================
' Creates a reversed stream from a decoding channel.
' HSTREAM BASS_FXDEF(BASS_FX_ReverseCreate)(HSTREAM chan, float dec_block, DWORD flags);
' ========================================================================================
DECLARE FUNCTION BASS_FX_ReverseCreate LIB "bass_fx.dll" ALIAS "BASS_FX_ReverseCreate" ( _
   BYVAL DWORD _                              ' __in HSTREAM chan
 , BYVAL SINGLE _                             ' __in float dec_block
 , BYVAL DWORD _                              ' __in DWORD flags
 ) AS DWORD                                   ' HSTREAM

' ========================================================================================
' Get the source channel handle of the reversed stream.
' HSTREAM BASS_FXDEF(BASS_FX_ReverseGetSource)(HSTREAM chan);
' ========================================================================================
DECLARE FUNCTION BASS_FX_ReverseGetSource LIB "bass_fx.dll" ALIAS "BASS_FX_ReverseGetSource" ( _
   BYVAL DWORD _                              ' __in HSTREAM chan
 ) AS DWORD                                   ' HSTREAM

'/*=============================================================================================
'   B P M (Beats Per Minute)
'==============================================================================================*/

'// NOTE: Supported only mono or stereo channels.

'// bpm flags
%BASS_FX_BPM_BKGRND  = 1   ' // if in use, then you can do other processing while detection's in progress. Not available in MacOSX yet. (BPM/Beat)
%BASS_FX_BPM_MULT2   = 2   ' // if in use, then will auto multiply bpm by 2 (if BPM < minBPM*2)

'// translation options
%BASS_FX_BPM_TRAN_X2       = 0                                ' // multiply the original BPM value by 2 (may be called only once & will change the original BPM as well!)
%BASS_FX_BPM_TRAN_2FREQ    = %BASS_FX_BPM_TRAN_X2       + 1   ' // BPM value to Frequency
%BASS_FX_BPM_TRAN_FREQ2    = %BASS_FX_BPM_TRAN_2FREQ    + 1   ' // Frequency to BPM value
%BASS_FX_BPM_TRAN_2PERCENT = %BASS_FX_BPM_TRAN_FREQ2    + 1   ' // BPM value to Percents
%BASS_FX_BPM_TRAN_PERCENT2 = %BASS_FX_BPM_TRAN_2PERCENT + 1   ' // Percents to BPM value

'typedef void (CALLBACK BPMPROCESSPROC)(DWORD chan, float percent);
'SUB BPMPROCESSPROC (BYVAL chan AS DWORD, BYVAL percent AS SINGLE)

'typedef void (CALLBACK BPMPROC)(DWORD handle, float bpm, void *user);
'SUB BPMPROC ( BYVAL handle AS DWORD, BYVAL bpm AS SINGLE, BYVAL user AS DWORD)

' ========================================================================================
' Get the original BPM of a decoding channel.
' float BASS_FXDEF(BASS_FX_BPM_DecodeGet)(DWORD chan, double startSec, double endSec,
' DWORD minMaxBPM, DWORD flags, BPMPROCESSPROC *proc);
' ========================================================================================
DECLARE FUNCTION BASS_FX_BPM_DecodeGet LIB "bass_fx.dll" ALIAS "BASS_FX_BPM_DecodeGet" ( _
   BYVAL DWORD _                              ' __in DWORD chan
 , BYVAL DOUBLE _                             ' __in double startSec
 , BYVAL DOUBLE _                             ' __in double endSec
 , BYVAL DWORD _                              ' __in DWORD minMaxBPM
 , BYVAL DWORD _                              ' __in DWORD flags
 , BYVAL DWORD _                              ' __in BPMPROCESSPROC *proc
 ) AS SINGLE                                  ' float

' ========================================================================================
' Enable getting BPM value by period of time in seconds.
' BOOL BASS_FXDEF(BASS_FX_BPM_CallbackSet)(DWORD handle, BPMPROC *proc, double period,
' DWORD minMaxBPM, DWORD flags, void *user);
' ========================================================================================
DECLARE FUNCTION BASS_FX_BPM_CallbackSet LIB "bass_fx.dll" ALIAS "BASS_FX_BPM_CallbackSet" ( _
   BYVAL DWORD _                              ' __in DWORD handle
 , BYVAL DWORD _                              ' __in BPMPROC *proc
 , BYVAL DOUBLE _                             ' __in double period
 , BYVAL DWORD _                              ' __in DWORD minMaxBPM
 , BYVAL DWORD _                              ' __in DWORD flags
 , BYREF ANY _                                ' __in void *user
 ) AS LONG                                    ' BOOL

' ========================================================================================
' Reset the buffers. Call this function after changing position.
' BOOL BASS_FXDEF(BASS_FX_BPM_CallbackReset)(DWORD handle);
' ========================================================================================
DECLARE FUNCTION BASS_FX_BPM_CallbackReset LIB "bass_fx.dll" ALIAS "BASS_FX_BPM_CallbackReset" ( _
   BYVAL DWORD _                              ' __in DWORD handle
 ) AS LONG                                    ' BOOL

' ========================================================================================
' Translate the given BPM to FREQ/PERCENT and vice versa or multiply BPM by 2.
' float BASS_FXDEF(BASS_FX_BPM_Translate)(DWORD handle, float val2tran, DWORD trans);
' ========================================================================================
DECLARE FUNCTION BASS_FX_BPM_Translate LIB "bass_fx.dll" ALIAS "BASS_FX_BPM_Translate" ( _
   BYVAL DWORD _                              ' __in DWORD handle
 , BYVAL SINGLE _                             ' __in float val2tran
 , BYVAL DWORD _                              ' __in DWORD trans
 ) AS SINGLE                                  ' float

' ========================================================================================
' Frees all resources used by a given handle (decode or callback bpm).
' BOOL BASS_FXDEF(BASS_FX_BPM_Free)(DWORD handle);
' ========================================================================================
DECLARE FUNCTION BASS_FX_BPM_Free LIB "bass_fx.dll" ALIAS "BASS_FX_BPM_Free" ( _
   BYVAL DWORD _                              ' __in DWORD handle
 ) AS LONG                                    ' BOOL

'/*=============================================================================================
'   B E A T
'==============================================================================================*/

'typedef void (CALLBACK BPMBEATPROC)(DWORD handle, double beatpos, void *user);
'SUB BPMBEATPROC (BYVAL handle AS DWORD, BYVAL beatpos AS DOUBLE, BYVAL user AS DWORD)

' ========================================================================================
' Enable getting BPM value by period of time in seconds.
' BOOL BASS_FXDEF(BASS_FX_BPM_BeatCallbackSet)(DWORD handle, BPMBEATPROC *proc, void *user);
' ========================================================================================
DECLARE FUNCTION BASS_FX_BPM_BeatCallbackSet LIB "bass_fx.dll" ALIAS "BASS_FX_BPM_BeatCallbackSet" ( _
   BYVAL DWORD _                              ' __in DWORD handle
 , BYVAL DWORD _                              ' __in BPMBEATPROC *proc
 , BYREF ANY _                                ' __in void *user
 ) AS LONG                                    ' BOOL

' ========================================================================================
' Reset the buffers. Call this function after changing position.
' BOOL BASS_FXDEF(BASS_FX_BPM_BeatCallbackReset)(DWORD handle);
' ========================================================================================
DECLARE FUNCTION BASS_FX_BPM_BeatCallbackReset LIB "bass_fx.dll" ALIAS "BASS_FX_BPM_BeatCallbackReset" ( _
   BYVAL DWORD _                              ' __in DWORD handle
 ) AS LONG                                    ' BOOL

' ========================================================================================
' Get the original BPM of a decoding channel.
' BOOL BASS_FXDEF(BASS_FX_BPM_BeatDecodeGet)(DWORD chan, double startSec, double endSec,
' DWORD flags, BPMBEATPROC *proc, void *user);
' ========================================================================================
DECLARE FUNCTION BASS_FX_BPM_BeatDecodeGet LIB "bass_fx.dll" ALIAS "BASS_FX_BPM_BeatDecodeGet" ( _
   BYVAL DWORD _                              ' __in DWORD chan
 , BYVAL DOUBLE _                             ' __in double startSec
 , BYVAL DOUBLE _                             ' __in double endSec
 , BYVAL DWORD _                              ' __in DWORD flags
 , BYVAL DWORD _                              ' __in BPMBEATPROC *proc,
 , BYREF ANY _                                ' __in void *user
 ) AS LONG                                    ' BOOL

' ========================================================================================
' Set new values for beat detection.
' BOOL BASS_FXDEF(BASS_FX_BPM_BeatSetParameters)(DWORD handle, float bandwidth,
' float centerfreq, float beat_rtime);
' ========================================================================================
DECLARE FUNCTION BASS_FX_BPM_BeatSetParameters LIB "bass_fx.dll" ALIAS "BASS_FX_BPM_BeatSetParameters" ( _
   BYVAL DWORD _                              ' __in DWORD handle
 , BYVAL SINGLE _                             ' __in float bandwidth
 , BYVAL SINGLE _                             ' __in float centerfreq
 , BYVAL SINGLE _                             ' __in float beat_rtime
 ) AS LONG                                    ' BOOL

' ========================================================================================
' Get current beat values.
' BOOL BASS_FXDEF(BASS_FX_BPM_BeatGetParameters)(DWORD handle, float *bandwidth,
' float *centerfreq, float *beat_rtime);
' ========================================================================================
DECLARE FUNCTION BASS_FX_BPM_BeatGetParameters LIB "bass_fx.dll" ALIAS "BASS_FX_BPM_BeatGetParameters" ( _
   BYVAL DWORD _                              ' __in  DWORD handle
 , BYREF SINGLE _                             ' __out float *bandwidth
 , BYREF SINGLE _                             ' __out float *centerfreq
 , BYREF SINGLE _                             ' __out float *beat_rtime
 ) AS LONG                                    ' BOOL

' ========================================================================================
' Frees all resources used by a given handle (decode or callback beat).
' BOOL BASS_FXDEF(BASS_FX_BPM_BeatFree)(DWORD handle);
' ========================================================================================
DECLARE FUNCTION BASS_FX_BPM_BeatFree LIB "bass_fx.dll" ALIAS "BASS_FX_BPM_BeatFree" ( _
   BYVAL DWORD _                              ' __in DWORD handle
 ) AS LONG                                    ' BOOL

#ENDIF   ' %BASS_FX_INC
